import { Program } from "typescript";
import { LanguageService, server } from "typescript/lib/tsserverlibrary.js";
import { LanguageServiceValidator } from "./LanguageServiceValidator.cjs";
/**
 * Provides the functionality to validate files.
 */
export declare class LanguageServicePlugin {
    /**
     * The context of the plugin.
     */
    private pluginInfo;
    /**
     * A component for validating files.
     */
    private validator;
    /**
     * The `nameof` language service.
     */
    private nameofLanguageService;
    /**
     * Initializes a new instance of the {@linkcode LanguageServicePlugin} class.
     *
     * @param pluginInfo
     * The context of the plugin.
     *
     * @param validator
     * A component for validating files.
     */
    constructor(pluginInfo: server.PluginCreateInfo, validator: LanguageServiceValidator);
    /**
     * Gets or sets the context of the plugin.
     */
    get PluginInfo(): server.PluginCreateInfo;
    /**
     * @inheritdoc
     */
    set PluginInfo(value: server.PluginCreateInfo);
    /**
     * Gets the language service of the plugin.
     */
    get LanguageService(): LanguageService;
    /**
     * Gets a component for validating files.
     */
    protected get Validator(): LanguageServiceValidator;
    /**
     * Gets the program of the transformation.
     */
    protected get Program(): Program | undefined;
    /**
     * Initializes the plugin.
     */
    Initialize(): void;
    /**
     * Refreshes the diagnostics.
     */
    Refresh(): void;
    /**
     * Decorates the language service if necessary.
     *
     * @returns
     * The decorated language service.
     */
    protected Decorate(): LanguageService;
}
