"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LanguageServicePluginModule = void 0;
const LanguageServicePlugin_cjs_1 = require("./LanguageServicePlugin.cjs");
const LanguageServiceValidator_cjs_1 = require("./LanguageServiceValidator.cjs");
/**
 * Provides the functionality to hook the validation into the TypeScript compiler.
 */
class LanguageServicePluginModule {
    /**
     * Initializes a new instance of the {@linkcode LanguageServicePlugin} class.
     *
     * @param tsLibrary
     * The TypeScript library.
     */
    constructor(tsLibrary) {
        /**
         * The plugins of the projects which have been initialized so far.
         */
        this.plugins = new Map();
        this.tsLibrary = tsLibrary;
        this.validator = new LanguageServiceValidator_cjs_1.LanguageServiceValidator(this.TS);
    }
    /**
     * Gets the TypeScript library.
     */
    get TS() {
        return this.tsLibrary;
    }
    /**
     * Gets the plugins of the projects which have been initialized so far.
     */
    get Plugins() {
        return this.plugins;
    }
    /**
     * Gets a component for validating files.
     */
    get Validator() {
        return this.validator;
    }
    /**
     * Creates a new plugin instance if necessary.
     *
     * @param createInfo
     * The options for creating the plugin instance.
     *
     * @returns
     * The decorated language service.
     */
    create(createInfo) {
        let projectName = createInfo.project.getProjectName();
        let plugin = this.Plugins.get(projectName);
        if (!plugin) {
            plugin = new LanguageServicePlugin_cjs_1.LanguageServicePlugin(createInfo, this.Validator);
            this.Plugins.set(projectName, plugin);
        }
        else {
            plugin.PluginInfo = createInfo;
            plugin.Initialize();
        }
        return plugin.LanguageService;
    }
    /**
     * Handles a configuration update.
     *
     * @param config
     * The new configuration.
     */
    onConfigurationChanged(config) {
        for (let plugin of this.Plugins.values()) {
            plugin.Refresh();
        }
    }
}
exports.LanguageServicePluginModule = LanguageServicePluginModule;
//# sourceMappingURL=LanguageServicePluginModule.cjs.map