import ts from "typescript";
import { LanguageService, server } from "typescript/lib/tsserverlibrary.js";
import { LanguageServicePlugin } from "./LanguageServicePlugin.cjs";
import { LanguageServiceValidator } from "./LanguageServiceValidator.cjs";
/**
 * Provides the functionality to hook the validation into the TypeScript compiler.
 */
export declare class LanguageServicePluginModule implements server.PluginModule {
    /**
     * The TypeScript library.
     */
    private tsLibrary;
    /**
     * The plugins of the projects which have been initialized so far.
     */
    private plugins;
    /**
     * A component for validating files.
     */
    private validator;
    /**
     * Initializes a new instance of the {@linkcode LanguageServicePlugin} class.
     *
     * @param tsLibrary
     * The TypeScript library.
     */
    constructor(tsLibrary: typeof ts);
    /**
     * Gets the TypeScript library.
     */
    protected get TS(): typeof ts;
    /**
     * Gets the plugins of the projects which have been initialized so far.
     */
    protected get Plugins(): Map<string, LanguageServicePlugin>;
    /**
     * Gets a component for validating files.
     */
    protected get Validator(): LanguageServiceValidator;
    /**
     * Creates a new plugin instance if necessary.
     *
     * @param createInfo
     * The options for creating the plugin instance.
     *
     * @returns
     * The decorated language service.
     */
    create(createInfo: server.PluginCreateInfo): LanguageService;
    /**
     * Handles a configuration update.
     *
     * @param config
     * The new configuration.
     */
    onConfigurationChanged(config: any): void;
}
