import { IErrorHandler } from "@typescript-nameof/common";
import { TransformerExtras } from "ts-patch";
import type ts = require("typescript");
import { IPluginConfig } from "./IPluginConfig.cjs";
import { ITypeScriptContext } from "./ITypeScriptContext.cjs";
import { TypeScriptFeatures } from "./TypeScriptFeatures.cjs";
/**
 * Provides the functionality to handle errors using `ts-patch` components.
 */
export declare class TSPatchFeatures extends TypeScriptFeatures {
    /**
     * A set of tools for interacting with `ts-patch`.
     */
    private extras;
    /**
     * Initializes a new instance of the {@linkcode TSPatchErrorHandler} class.
     *
     * @param extras
     * A set of tools for interacting with `ts-patch`.
     *
     * @param config
     * The configuration of the plugin.
     *
     * @param errorHandler
     * A component for reporting errors.
     */
    constructor(extras: TransformerExtras, config?: IPluginConfig, errorHandler?: IErrorHandler<ts.Node, ITypeScriptContext>);
    /**
     * @inheritdoc
     */
    get TypeScript(): typeof ts;
    /**
     * Gets a set of tools for interacting with `ts-patch`.
     */
    get Extras(): TransformerExtras;
    /**
     * @inheritdoc
     *
     * @returns
     * The newly created error handler.
     */
    protected InitializeErrorHandler(): IErrorHandler<ts.Node, ITypeScriptContext>;
}
