"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TypeScriptFeatures = void 0;
const node_module_1 = require("node:module");
const node_path_1 = require("node:path");
const common_1 = require("@typescript-nameof/common");
const TypeScriptErrorHandler_cjs_1 = require("../Diagnostics/TypeScriptErrorHandler.cjs");
/**
 * Provides features for transforming TypeScript code.
 */
class TypeScriptFeatures extends common_1.TransformerFeatures {
    /**
     * Initializes a new instance of the {@linkcode TransformerFeatures TypeScriptFeatures<T>} class.
     *
     * @param config
     * The configuration of the plugin.
     *
     * @param errorHandler
     * A component for reporting errors.
     */
    constructor(config, errorHandler) {
        super(errorHandler);
        this.config = config;
    }
    /**
     * Gets an instance of a TypeScript compiler.
     */
    get TypeScript() {
        var _a;
        if ((_a = this.Config) === null || _a === void 0 ? void 0 : _a.tsLibrary) {
            if (typeof this.Config.tsLibrary === "string") {
                return this.Require(this.Config.tsLibrary);
            }
            else {
                return this.Config.tsLibrary;
            }
        }
        else {
            return this.TypeScriptFallback;
        }
    }
    /**
     * Gets a fallback instance of typescript in case no `typescript` instance was found in the configuration.
     */
    get TypeScriptFallback() {
        return this.Require("typescript");
    }
    /**
     * Gets the configuration of the transformer.
     */
    get Config() {
        return this.config;
    }
    /**
     * Reports the specified {@linkcode error}.
     *
     * @param location
     * The location of the specified {@linkcode node}.
     *
     * @param node
     * The node related to the error.
     *
     * @param context
     * The context of the operation.
     *
     * @param error
     * The error to process.
     */
    ReportError(location, node, context, error) {
        var _a;
        (_a = this.ErrorHandler) === null || _a === void 0 ? void 0 : _a.Report(location, node, context, error);
    }
    /**
     * Initializes a new error handler.
     *
     * @returns
     * The newly created error handler.
     */
    InitializeErrorHandler() {
        return new TypeScriptErrorHandler_cjs_1.TypeScriptErrorHandler(this);
    }
    /**
     * Imports the module identified by the specified {@linkcode moduleSpecifier} using a {@linkcode require} call.
     *
     * @param moduleSpecifier
     * The specifier of the module to import.
     *
     * @returns
     * The content of the imported module.
     */
    Require(moduleSpecifier) {
        return (0, node_module_1.createRequire)((0, node_path_1.join)(process.cwd(), ".cjs"))(moduleSpecifier);
    }
}
exports.TypeScriptFeatures = TypeScriptFeatures;
//# sourceMappingURL=TypeScriptFeatures.cjs.map