import type { TsCompilerInstance } from "ts-jest/dist/types";
import { TransformerExtras } from "ts-patch";
import { Program, SourceFile, TransformationContext, Transformer, TransformerFactory } from "typescript";
import { server } from "typescript/lib/tsserverlibrary";
import * as text from "./text/index.cjs";
import * as adapter from "./Transformation/TypeScriptAdapter.cjs";
import * as vanillaFeatures from "./Transformation/TypeScriptFeatures.cjs";
import * as meta from "./version.cjs";
/**
 * Represents the context of a language service plugin creation.
 */
type PluginContext = Parameters<server.PluginModuleFactory>[0];
/**
 * Creates a `nameof` transformer for vanilla TypeScript.
 *
 * @param context
 * The context of the TypeScript transformation.
 */
declare function nameof(context: TransformationContext): Transformer<SourceFile>;
/**
 * Creates a language service for validating `nameof` calls.
 *
 * @param context
 * The context of the TypeScript language service.
 */
declare function nameof(context: PluginContext): server.PluginModule;
/**
 * Creates a `nameof` transformer for `ts-patch`.
 *
 * @param program
 * The program which is being transformed.
 *
 * @param config
 * The configuration of the plugin.
 *
 * @param extras
 * A set of components to interact with `ts-patch`.
 */
declare function nameof(program: Program, config?: Record<string, unknown>, extras?: TransformerExtras): TransformerFactory<SourceFile>;
declare namespace nameof {
    /**
     * The version of the plugin.
     */
    export import version = meta.version;
    export import replaceInFiles = text.replaceInFiles;
    export import replaceInText = text.replaceInText;
    /**
     * Creates a transformer for `ts-jest`.
     *
     * @param compiler
     * The `ts-jest` compiler instance.
     *
     * @returns
     * The newly created {@linkcode TransformerFactory}.
     */
    function factory(compiler: TsCompilerInstance): TransformerFactory<SourceFile>;
    export import TypeScriptAdapter = adapter.TypeScriptAdapter;
    export import TypeScriptFeatures = vanillaFeatures.TypeScriptFeatures;
}
export = nameof;
